@@ -12,12 +12,16 @@ import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_codecommit._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
+import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_lambda_nodejs._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-amplify", "1.108.1", __name__[0:-6], "aws-amplify@1.108.1.jsii.tgz"
+    "@aws-cdk/aws-amplify", "1.156.1", __name__[0:-6], "aws-amplify@1.156.1.jsii.tgz"
 )
 
 __all__ = [
